import commonjs from 'rollup-plugin-commonjs'
import nodeResolve from 'rollup-plugin-node-resolve'
import postcss from 'rollup-plugin-postcss'
import svelte from 'rollup-plugin-svelte'

// PostCSS plugins
import atImport from 'postcss-import'
import presetEnv from 'postcss-preset-env'
import tailwind from 'tailwindcss'

const isProduction = process.env.NODE_ENV === 'production'

export default {
  input: 'src/main.js',
  output: {
    dir: 'build',
    format: 'iife'
  },
  plugins: [
    nodeResolve(),
    commonjs({
      include: 'node_modules/**'
    }),
    svelte({
      emitCss: true
    }),
    postcss({
      extract: true,
      minimize: isProduction,
      plugins: [
        atImport(),
        tailwind({
          theme: {
            container: {
              center: true,
              padding: '1rem'
            },
            screens: {
              sm: '640px',
              md: '768px',
              lg: '1024px',
              xl: '1280px',
              dark: {'raw': '(prefers-color-scheme: dark)'},
              light: {'raw': '(prefers-color-scheme: light)'}
            }
          }
        }),
        presetEnv({
          stage: 1
        })
      ]
    })
  ]
}
